@@ -1,7 +1,7 @@
 package App::DateUtils;
 
-our $DATE = '2016-06-28'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-29'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -98,7 +98,7 @@ sub parse_date {
             }
         } elsif ($mod =~ /^DateTime::Format::Natural/) {
             my $dt = $parser->parse_datetime($date);
-            if ($parser->{success}) {
+            if ($parser->success) {
                 $rec->{is_parseable} = 1;
                 $rec->{as_epoch} = $dt->epoch;
                 $rec->{as_datetime_obj} = "$dt";
@@ -156,7 +156,15 @@ $SPEC{parse_duration} = {
     args => {
         module => {
             schema  => ['str*', in=>[
-                'DateTime::Format::Duration',
+                'DateTime::Format::Alami::EN',
+                'DateTime::Format::Alami::ID',
+
+                # parsing duration with DF:Natural is not like what one would
+                # expect. it tries to find 2 dates in the text. even text like
+                # '2 days' would result in 1 date, which is the current date.
+
+                #'DateTime::Format::Natural',
+
                 'Time::Duration::Parse',
             ]],
             default => 'Time::Duration::Parse',
@@ -171,10 +179,12 @@ sub parse_duration {
     my $mod = $args{module};
 
     my $parser;
-    if ($mod eq 'DateTime::Format::Duration') {
-        require DateTime::Format::Duration;
-        $parser = DateTime::Format::Duration->new(
-        );
+    if ($mod eq 'DateTime::Format::Alami::EN') {
+        require DateTime::Format::Alami::EN;
+        $parser = DateTime::Format::Alami::EN->new();
+    } elsif ($mod eq 'DateTime::Format::Alami::ID') {
+        require DateTime::Format::Alami::ID;
+        $parser = DateTime::Format::Alami::ID->new();
     } elsif ($mod eq 'Time::Duration::Parse') {
         require Time::Duration::Parse;
     }
@@ -182,12 +192,14 @@ sub parse_duration {
     my @res;
     for my $dur (@{ $args{durations} }) {
         my $rec = { original => $dur };
-        if ($mod eq 'DateTime::Format::Duration') {
-            my $dtdur = $parser->parse_duration($dur);
-            if ($dtdur) {
+        if ($mod =~ /^DateTime::Format::Alami/) {
+            my $res = $parser->parse_datetime_duration($dur, {format=>'combined'});
+            if ($res) {
+                require DateTime::Format::Duration::ISO8601;
+                my $dtdurf = DateTime::Format::Duration::ISO8601->new;
                 $rec->{is_parseable} = 1;
-                $rec->{as_dtdur_obj} = "$dtdur";
-                $rec->{as_secs} = $dtdur->in_units('seconds');
+                $rec->{as_dtdur_obj} = $dtdurf->format_duration($res->{Duration});
+                $rec->{as_secs} = $res->{seconds};
             } else {
                 $rec->{is_parseable} = 0;
             }
@@ -208,16 +220,40 @@ sub parse_duration {
     [200, "OK", \@res];
 }
 
-$SPEC{parse_duration_using_df_duration} = {
+$SPEC{parse_duration_using_df_alami_en} = {
     v => 1.1,
-    summary => 'Parse date string(s) using DateTime::Format::Duration',
+    summary => 'Parse date string(s) using DateTime::Format::Alami::EN',
     args => {
         %durations_arg,
     },
 };
-sub parse_duration_using_df_duration {
+sub parse_duration_using_df_alami_en {
     my %args = @_;
-    parse_duration(module=>'DateTime::Format::Duration', %args);
+    parse_duration(module=>'DateTime::Format::Alami::EN', %args);
+}
+
+$SPEC{parse_duration_using_df_alami_id} = {
+    v => 1.1,
+    summary => 'Parse date string(s) using DateTime::Format::Alami::ID',
+    args => {
+        %durations_arg,
+    },
+};
+sub parse_duration_using_df_alami_id {
+    my %args = @_;
+    parse_duration(module=>'DateTime::Format::Alami::ID', %args);
+}
+
+$SPEC{parse_duration_using_td_parse} = {
+    v => 1.1,
+    summary => 'Parse date string(s) using Time::Duration::Parse',
+    args => {
+        %durations_arg,
+    },
+};
+sub parse_duration_using_td_parse {
+    my %args = @_;
+    parse_duration(module=>'Time::Duration::Parse', %args);
 }
 
 $SPEC{dateconv} = {
@@ -342,7 +378,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.06 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-28.
+This document describes version 0.07 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-29.
 
 =head1 SYNOPSIS
 
@@ -365,7 +401,11 @@ date/time:
 
 =item * L<parse-duration>
 
-=item * L<parse-duration-using-df-duration>
+=item * L<parse-duration-using-df-alami-en>
+
+=item * L<parse-duration-using-df-alami-id>
+
+=item * L<parse-duration-using-td-parse>
 
 =back
 
@@ -382,7 +422,7 @@ Examples:
 
 =item * Convert "today" to epoch:
 
- dateconv(date => "today"); # -> 1467072000
+ dateconv(date => "today"); # -> 1467158400
 
 =item * Convert epoch to ymd:
 
@@ -452,8 +492,18 @@ Result:
    200,
    "OK",
    [
-     { is_parseable => 0, original => "23 sep 2015" },
-     { is_parseable => 0, original => "tomorrow" },
+     {
+       as_datetime_obj => "2015-09-23T00:00:00",
+       as_epoch        => 1442966400,
+       is_parseable    => 1,
+       original        => "23 sep 2015",
+     },
+     {
+       as_datetime_obj => "2016-06-30T00:00:00",
+       as_epoch        => 1467244800,
+       is_parseable    => 1,
+       original        => "tomorrow",
+     },
      { is_parseable => 0, original => "foo" },
    ],
    {},
@@ -599,9 +649,61 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 parse_duration_using_df_duration(%args) -> [status, msg, result, meta]
+=head2 parse_duration_using_df_alami_en(%args) -> [status, msg, result, meta]
 
-Parse date string(s) using DateTime::Format::Duration.
+Parse date string(s) using DateTime::Format::Alami::EN.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<durations>* => I<array[str]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 parse_duration_using_df_alami_id(%args) -> [status, msg, result, meta]
+
+Parse date string(s) using DateTime::Format::Alami::ID.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<durations>* => I<array[str]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 parse_duration_using_td_parse(%args) -> [status, msg, result, meta]
+
+Parse date string(s) using Time::Duration::Parse.
 
 This function is not exported.
 
